default_app_config = 'currencyware.apps.CurrencywareConfig'

__author__ = 'Val Neekman @ Neekware Inc. [@vneekman]'
__description__ = "A Django application to translate currency names"
__version__ = '0.1.3'
