# Generated by Django 2.0.8 on 2018-08-18 11:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('code', models.CharField(help_text='Currency code', max_length=3, primary_key=True, serialize=False, verbose_name='Code')),
                ('name', models.CharField(blank=True, help_text='Curreny name (english)', max_length=60, null=True, verbose_name='Name')),
                ('number', models.CharField(blank=True, help_text='Numeric code', max_length=3, null=True, verbose_name='Number')),
                ('unit', models.IntegerField(blank=True, help_text='Currency unit', null=True, verbose_name='Unit')),
                ('symbol', models.CharField(blank=True, help_text='Currency symbol', max_length=10, null=True, verbose_name='Symbol')),
                ('country', models.CharField(blank=True, help_text='Primary currency in these countries', max_length=255, null=True, verbose_name='Country')),
            ],
            options={
                'verbose_name': 'Currency',
                'verbose_name_plural': 'Currencies',
            },
        ),
        migrations.CreateModel(
            name='Rate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(help_text='Currency code', max_length=3, verbose_name='Code')),
                ('name', models.CharField(blank=True, help_text='Curreny name (english)', max_length=100, null=True, verbose_name='Name')),
                ('rate', models.FloatField(default=0.0, help_text='Currency forex rate', verbose_name='Rate')),
                ('date', models.DateTimeField(help_text="Rate's date", verbose_name='Date')),
            ],
            options={
                'verbose_name': 'Rate',
                'verbose_name_plural': 'Rates',
            },
        ),
    ]
